from django.contrib.auth import get_user_model
from django.db import migrations


def wrap(apps, schema_editor):
    for user in get_user_model().objects.exclude(notification_settings=None):
        user.notification_settings = {
            'events': user.notification_settings
        }
        user.save(update_fields=['notification_settings'])


def unwrap(apps, schema_editor):
    for user in get_user_model().objects.exclude(notification_settings=None):
        user.notification_settings = user.notification_settings.get('events', {})
        user.save(update_fields=['notification_settings'])


class Migration(migrations.Migration):

    dependencies = [
        ('whistle', '0004_rename_mail_to_email'),
    ]

    operations = [
        migrations.RunPython(wrap, unwrap),
    ]



from django.contrib.auth import get_user_model
from django.core.management import call_command
from django.db import migrations


def mail_to_email(apps, schema_editor):
    try:
        call_command('copy_channel_settings', 'mail', 'email', delete=True)
    except:
        pass


def email_to_mail(apps, schema_editor):
    try:
        call_command('copy_channel_settings', 'email', 'mail', delete=True)
    except:
        pass


class Migration(migrations.Migration):

    dependencies = [
        ('whistle', '0003_rename_web_settings'),
    ]

    operations = [
        migrations.RunPython(mail_to_email, email_to_mail),
    ]



from django.conf import settings
from django.core.cache.backends.base import DEFAULT_TIMEOUT

EVENTS = getattr(settings, 'WHISTLE_NOTIFICATION_EVENTS', [])
CHANNELS = getattr(settings, 'WHISTLE_CHANNELS', ['web', 'email'])
AVAILABILITY_HANDLER = getattr(settings, 'WHISTLE_AVAILABILITY_HANDLER', None)
URL_HANDLER = getattr(settings, 'WHISTLE_URL_HANDLER', None)
URL_PARAM = getattr(settings, 'WHISTLE_URL_PARAM', 'read-notification')
TIMEOUT = getattr(settings, 'WHISTLE_CACHE_TIMEOUT', DEFAULT_TIMEOUT)
USE_RQ = getattr(settings, 'WHISTLE_USE_RQ', True)
REDIS_QUEUE = getattr(settings, 'WHISTLE_REDIS_QUEUE', 'default')
SIGNING_KEY = getattr(settings, 'WHISTLE_SIGNING_KEY', settings.SECRET_KEY)
SIGNING_SALT = getattr(settings, 'WHISTLE_SIGNING_SALT', 'whistle')
AUTH_USER_MODEL = getattr(settings, 'WHISTLE_AUTH_USER_MODEL', settings.AUTH_USER_MODEL)

if 'push' in CHANNELS and 'fcm_django' not in settings.INSTALLED_APPS:
    raise ValueError('fcm_django is required for push notifications. Either install the app or remove push channel from whistle channels')
